# occlib-py

occlib is the Open Cinema Collective's python Library template.

occlib comes pre-built with a number of tools for formatting, linting and 
testing.

## Installation

``pip install occlib``

## Getting Started
For full documentation:
[read the docs](https://opencinemac.github.io/occlib-py/).

For library development guide, 
[read the docs](https://opencinemac.github.io/occlib-py/).

### Prerequisites

Python 3.8+

## Authors

* **Billy Peake** - *Initial work*

